@@ -22,7 +22,8 @@ from PyQtHelpers import LayoutWidget, LayoutLayout, ButtonBoxButton, FormRow, \
 from commands import DomainEntity, Command, CommandMenu, CommandEvent, \
         BoundCommandMenu, BoundCommandMenuItem
 
-from user_attr import UserAttr, Nullable, AttrNumeric, UseCachedValue
+from user_attr import hasextendedattr, getextendedattr, setextendedattr, \
+        UserAttr, Nullable, AttrNumeric, UseCachedValue
 from sqlalchemy_helper import ModelObject, ModelSession, PBSessionMaker, UUID, \
         ValidationError, user_message, Message, instanceEvent, sessionExtension
 
