@@ -368,7 +368,8 @@ class BoundCommandMenuItem(object):
 
     def activatedProxy(self, index):
         if self.cmd.requireSelection and index is None:
-            print "none selected"
+            import warnings
+            warnings.warn("No selected view index for {0}".format(self.cmd.name))
         else:
             if self.cmd.viewRelated:
                 handle = index
