@@ -31,4 +31,4 @@ def xdg_open(file):
         except ImportError as e:
             os.system('start {0}'.format(file))
     else:
-        os.system('xdg-open {0}'.format(file))
+        os.system('xdg-open {0}'.format(file.replace(';', r'\;').replace('&', r'\&')))
